## Refreezing
There are two model options for computing refreezing.  The default option estimates refreezing based on the mean annual air temperature ([Woodward et al. 1997](https://www.cambridge.org/core/journals/annals-of-glaciology/article/influence-of-superimposedice-formation-on-the-sensitivity-of-glacier-mass-balance-to-climate-change/84DFA08E9CC8F28BE0729F1EBF4DA4E1)), while the alternative is based on heat conduction ([Huss and Hock, 2015](https://www.frontiersin.org/articles/10.3389/feart.2015.00054/full)).

### Option 1: Mean annual air temperature
For the default option, refreezing (R) is calculated for each elevation bin as a function of its weighted annual mean air temperature (Ta) following [Woodward et al. (1997)](https://www.cambridge.org/core/journals/annals-of-glaciology/article/influence-of-superimposedice-formation-on-the-sensitivity-of-glacier-mass-balance-to-climate-change/84DFA08E9CC8F28BE0729F1EBF4DA4E1)):
$$R = -0.0069 \cdot T_{a} + 0.000096$$
The weighted annual mean accounts for the number of days in each month. Refreezing cannot be negative. The model assumes that refreezing occurs in the snowpack as opposed to being superimposed ice, so in the ablation zone the refreezing cannot exceed the snow depth. Since this option estimates annual refreezing, the equation above provides the maximum amount of potential refreezing. Each year, the potential refreezing is reset in October as this is the transition season from predominantly summer melt to winter accumulation. Therefore, it is possible that accumulated snow may melt and refreeze diurnally. The model replicates this physical behavior by first determining the amount of snow that has melted in that month. If the refreezing potential is greater than zero, the model assumes the snow melts and refreezes in the snow pack. Refreezing cannot exceed the amount of snow melt in any given month. The amount of refreezing is then subtracted from the potential refreezing until the potential refreezing is fully depleted or reset. Once the snow and refreezing completely melts, the model can melt the underlying ice/firn/snow.  This model is used as the default because it is computationally cheap compared to the alternative.

### Option 2: Heat conduction
The alternative option is to estimate refreezing using modeled snow and firn temperatures based on heat conduction as described by [Huss and Hock (2015)](https://www.frontiersin.org/articles/10.3389/feart.2015.00054/full). This option is significantly more computationally expensive. The code for this section was translated from the IDL code used in [Huss and Hock (2015)](https://www.frontiersin.org/articles/10.3389/feart.2015.00054/full), which potentially has an error in the heat conduction equation where the temperature in each layer is divided by a factor of 2 that Lilian Schuster identified is not physically-derived (as of 2021 - this error has not been fixed). This option should thus be used with caution until further developed.